==> 1.0.6%2B9.tar.gz: lib/core-plugin.dart <==
library core_plugin;

export 'package:get_it/get_it.dart';
export 'awsomeDialogs/awesome_dialog.dart';
export 'Common/CommonUltil.dart';
export 'Common/CommonWidget.dart';
export 'CommonApi/CommonApi.dart';
export 'CommonApi/ResultObject.dart';
export 'CommonApi/CoreModelFinter.dart';
export 'EnumToString/enum_to_string.dart';
export 'FabCirularMenu/FabCircularMenu.dart';
export 'HiveReponsitory/ResponsitoryObject.dart';
export 'ModalBottomSheet/modal_bottom_sheet.dart';
export 'Nice_Button/nice_button.dart';
export 'Responsive_widgets/responsive_widgets.dart';
export 'package:flutter_screenutil/flutter_screenutil.dart';
export 'Setting_UI/settings_ui.dart';
export 'ShadowStyle/shadow.dart';
export 'TreeViews/TreeNode.dart';
export 'TreeViews/TreeNode.dart';
export 'Widget_animator/widget_animator.dart';
export 'package:animated_text_kit/animated_text_kit.dart';
export 'package:json_annotation/json_annotation.dart';
export 'package:flutter_slidable/flutter_slidable.dart';
export 'package:rxdart/rxdart.dart';
export 'package:path_provider/path_provider.dart';
export 'package:cached_network_image/cached_network_image.dart';
export 'package:pull_to_refresh/pull_to_refresh.dart';
export 'package:fluro/fluro.dart';
export 'package:hive/hive.dart';
export 'package:hive_flutter/hive_flutter.dart';
export 'package:provider/provider.dart';
export 'package:flutter_bloc/flutter_bloc.dart';
export 'package:local_auth/local_auth.dart';
export 'package:shared_preferences/shared_preferences.dart';
export 'package:connectivity/connectivity.dart';
export 'package:equatable/equatable.dart';
import 'package:flutter/services.dart';

class CorePluginFlutter {
  static const MethodChannel _channel =
      const MethodChannel('core_plugin_flutter');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }
}

==> 1.0.7%2B9.tar.gz: lib/core-plugin.dart <==
library core_plugin;

/**singleton denpendency */
export 'package:get_it/get_it.dart';

/**Multiple language */
export 'package:flutter_localizations/flutter_localizations.dart';
export 'MultipleLanguage/AppLocalizations.dart';
export 'MultipleLanguage/AppTranslations.dart';

/**dialog */
export 'awsomeDialogs/awesome_dialog.dart';

/**json serial */
export 'package:json_annotation/json_annotation.dart';

/**Common Ultil, widget */
export 'Common/CommonUltil.dart';
export 'Common/CommonWidget.dart';
export 'CommonApi/CommonAppApi.dart';
export 'CommonApi/ResultObject.dart';
export 'CommonApi/CoreModelFinter.dart';

/**Enum parse string */
export 'EnumToString/enum_to_string.dart';

/**menu float buttom */
export 'FabCirularMenu/FabCircularMenu.dart';

/**Reponsitory cache */
export 'package:shared_preferences/shared_preferences.dart';
export 'package:hive/hive.dart';
export 'package:hive_flutter/hive_flutter.dart';
export 'HiveReponsitory/ResponsitoryObject.dart';

/**dialog modal buttom sheet */
export 'ModalBottomSheet/modal_bottom_sheet.dart';

/**button nice */
export 'Nice_Button/nice_button.dart';

/**responsive_widgets */
export 'package:flutter_screenutil/flutter_screenutil.dart';
export 'Responsive_widgets/responsive_widgets.dart';

/**settingsui */
export 'Setting_UI/settings_ui.dart';

/**shadow widget */
export 'ShadowStyle/shadow.dart';

/**TreeView widget */
export 'TreeViews/TreeNode.dart';
export 'TreeViews/TreeView.dart';

/**animation for widget */
export 'Widget_animator/widget_animator.dart';
export 'package:animated_text_kit/animated_text_kit.dart';

/**switch layout */
export 'package:flutter_slidable/flutter_slidable.dart';

/**state management */
export 'package:equatable/equatable.dart';
export 'package:rxdart/rxdart.dart';
export 'package:path_provider/path_provider.dart';
export 'package:provider/provider.dart';
export 'package:flutter_bloc/flutter_bloc.dart';

/**Image caching */
export 'package:cached_network_image/cached_network_image.dart';

/**pull to refresh list */
export 'package:pull_to_refresh/pull_to_refresh.dart';

/**router  */
export 'FluroRouter/fluro.dart';

/**local author  */
export 'package:local_auth/local_auth.dart';

/**local author  */
export 'package:connectivity/connectivity.dart';

/**using channel code native  */
import 'package:flutter/services.dart';

class CorePluginFlutter {
  static const MethodChannel _channel =
      const MethodChannel('core_plugin_flutter');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }
}
